@@ -8,11 +8,16 @@ from .settings import Settings as ST
 
 
 def conversion():
+    """
+
+    :return:
+    """
     result, file_name = get_test_plan(swagger_url=ST.swagger_url, swagger_url_json_path=ST.swagger_url_json_path,
                                       swagger_json=ST.swagger_json)
     jmeterTestPlan = etree.Element("jmeterTestPlan")
     hashTree = jmeter_test_plan(jmeterTestPlan)
-    testPlan = test_plan(hashTree)
+    testPlan = test_plan(hashTree, file_name)
+    # Arguments = arguments(testPlan)
     threadGroup = thread_group(testPlan)
     controller(threadGroup, result)
     etree.tostring(jmeterTestPlan, pretty_print=True)
